@@ -21,13 +21,14 @@ let filter what_bus message =
   None
 
 let add_filter what_bus get_bus =
-  lwt bus = get_bus () in
+  let%lwt bus = get_bus () in
   let _ = Lwt_sequence.add_r (filter what_bus) (OBus_connection.incoming_filters bus) in
   Lwt_list.iter_p
     (fun typ -> OBus_bus.add_match bus (OBus_match.rule ~typ ()))
     [ `Method_call; `Method_return; `Error; `Signal ]
 
-lwt () =
-  lwt () = add_filter "session" OBus_bus.session <&> add_filter "system" OBus_bus.system in
-  lwt () = Lwt_io.printlf "type Ctrl+C to stop" in
+let () = Lwt_main.run begin
+  let%lwt () = add_filter "session" OBus_bus.session <&> add_filter "system" OBus_bus.system in
+  let%lwt () = Lwt_io.printlf "type Ctrl+C to stop" in
   fst (wait ())
+end
